@@ -11,15 +11,15 @@
 /*
  * Evaluate boolean AND
  */
-value *eval_bool_and(expr *a, expr *b)
+value *eval_bool_and(arena_state *s, expr *a, expr *b)
 {
   int bool_val;
   value *val;
   
   sanity(a && b);
 
-  val = eval_expr(a);
-  value_cast_inplace(&val, VALUE_TYPE_BOOL);
+  val = eval_expr(s, a);
+  value_cast_inplace(s, &val, VALUE_TYPE_BOOL);
   bool_val = val->value_u.bool_val;
   value_free(val);
   
@@ -27,8 +27,8 @@ value *eval_bool_and(expr *a, expr *b)
     return value_make_bool(0);
   }
   
-  val = eval_expr(b);
-  value_cast_inplace(&val, VALUE_TYPE_BOOL);
+  val = eval_expr(s, b);
+  value_cast_inplace(s, &val, VALUE_TYPE_BOOL);
   
   return val;
 }
@@ -36,15 +36,15 @@ value *eval_bool_and(expr *a, expr *b)
 /*
  * Evaluate boolean OR
  */
-value *eval_bool_or(expr *a, expr *b)
+value *eval_bool_or(arena_state *s, expr *a, expr *b)
 {
   int bool_val;
   value *val;
 
   sanity(a && b);
 
-  val = eval_expr(a);
-  value_cast_inplace(&val, VALUE_TYPE_BOOL);
+  val = eval_expr(s, a);
+  value_cast_inplace(s, &val, VALUE_TYPE_BOOL);
   bool_val = val->value_u.bool_val;
   value_free(val);
   
@@ -52,8 +52,8 @@ value *eval_bool_or(expr *a, expr *b)
     return value_make_bool(1);
   }
   
-  val = eval_expr(b);
-  value_cast_inplace(&val, VALUE_TYPE_BOOL);
+  val = eval_expr(s, b);
+  value_cast_inplace(s, &val, VALUE_TYPE_BOOL);
   
   return val;
 }
@@ -61,19 +61,19 @@ value *eval_bool_or(expr *a, expr *b)
 /*
  * Evaluate conditional expression
  */
-value *eval_expr_if(expr *ex)
+value *eval_expr_if(arena_state *s, expr *ex)
 {
   value *test, *res;
   
   sanity(ex && ex->inner && ex->index && ex->elif);
   
-  test = eval_expr(ex->inner);
-  value_cast_inplace(&test, VALUE_TYPE_BOOL);
+  test = eval_expr(s, ex->inner);
+  value_cast_inplace(s, &test, VALUE_TYPE_BOOL);
   
   if (test->value_u.bool_val) {
-    res = eval_expr(ex->index);
+    res = eval_expr(s, ex->index);
   } else {
-    res = eval_expr(ex->elif);
+    res = eval_expr(s, ex->elif);
   }
   
   value_free(test);
