@@ -11,11 +11,7 @@
  */
 arena_state *state_alloc(void)
 {
-  arena_state *res;
-
-  res = oom(calloc(1, sizeof(arena_state)));
-  res->resource_max = RESOURCE_MAX;
-  return res;
+  return oom(calloc(1, sizeof(arena_state)));
 }
 
 /*
