@@ -21,9 +21,11 @@ value *call_function(arena_state *s, const char *name, signature *sig,
   
   sanity(name && sig && (argc == 0 || argv));
 
-  if (s->except_flag == 0) {
+  if (!s->except_flag && !s->exit_flag) {
     call_check(s, name, sig, argc, argv);
+  }
 
+  if (!s->except_flag && !s->exit_flag) {
     switch (sig->type) {
       case FUNCTION_TYPE_BUILTIN:
         sanity(sig->call_u.builtin_vector);
@@ -39,7 +41,7 @@ value *call_function(arena_state *s, const char *name, signature *sig,
     result = value_make_void();
   }
  
-  if (s->except_flag != 0) {
+  if (s->except_flag || s->exit_flag) {
     rettype = '?';
   } else {
     rettype = sig->rettype;
@@ -48,7 +50,6 @@ value *call_function(arena_state *s, const char *name, signature *sig,
   if (rettype != '?' && call_typechar(result) != tolower(rettype)) {
     if (islower(rettype) || rettype == 'P') {
       realtype = result->type;
-      value_free(result);
       fatal(s, "function `%s': return type mismatch (`%s' instead of `%s')",
         name, call_typename(realtype),
         call_typename(call_chartype(rettype))
