@@ -25,10 +25,16 @@ void value_add_to_array(value *arr, value *val)
 
   if (av->size <= av->len) {
     av->size += ARRAY_GROWTH;
-    elems = oom(realloc(av->value, av->size * sizeof(value *)));
+    elems = oom(realloc(av->value, (av->size + 1) * sizeof(value *)));
     av->value = elems;
   }
   av->value[av->len++] = value_copy(val);
+  
+  /*
+   * Maintain a NULL sentinel at the end of the pointer array.
+   * This makes iteration over the array entries easy.
+   */
+  av->value[av->len] = NULL;
 }
 
 /*
