@@ -266,6 +266,7 @@ static stdlib_func std[] = {
   { "dyn_call_int",	dyn_call_int,		2,	"rs",	'?'	},
   { "dyn_call_float",	dyn_call_float,		2,	"rs",	'?'	},
   { "dyn_call_ptr",	dyn_call_ptr,		2,	"rs",	'?'	},
+  { "cfloat",		dyn_c_float,		1,	"F",	'?'	},
 
   /* memory handling functions */
   { "is_mem_resource",	mem_is_resource,	1,	"r",	'b'	},
@@ -281,12 +282,14 @@ static stdlib_func std[] = {
   { "mputint",		mem_put_int,		3,	"rii",	'b'	},
   { "mputfloat",	mem_put_float,		3,	"rif",	'b'	},
   { "mputdouble",	mem_put_double,		3,	"rif",	'b'	},
+  { "mputstring",	mem_put_string,		3,	"riS",	'b'	},
   { "mputptr",		mem_put_pointer,	3,	"rir",	'b'	},
   { "mgetchar",		mem_get_char,		2,	"ri",	'?'	},
   { "mgetshort",	mem_get_short,		2,	"ri",	'?'	},
   { "mgetint",		mem_get_int,		2,	"ri",	'?'	},
   { "mgetfloat",	mem_get_float,		2,	"ri",	'?'	},
   { "mgetdouble",	mem_get_double,		2,	"ri",	'?'	},
+  { "mgetstring",	mem_get_string,		3,	"rii",	'?'	},
   { "mgetptr",		mem_get_pointer,	3,	"rib",	'?'	},
   { "mstring",		mem_string,		2,	"ri",	'?'	},
   { "is_rw",		mem_is_rw,		1,	"r",	'b'	},
