@@ -252,12 +252,14 @@ value *mem_put_short(arena_state *s, unsigned int, value **);
 value *mem_put_int(arena_state *s, unsigned int, value **);
 value *mem_put_float(arena_state *s, unsigned int, value **);
 value *mem_put_double(arena_state *s, unsigned int, value **);
+value *mem_put_string(arena_state *s, unsigned int, value **);
 value *mem_put_pointer(arena_state *s, unsigned int, value **);
 value *mem_get_char(arena_state *s, unsigned int, value **);
 value *mem_get_short(arena_state *s, unsigned int, value **);
 value *mem_get_int(arena_state *s, unsigned int, value **);
 value *mem_get_float(arena_state *s, unsigned int, value **);
 value *mem_get_double(arena_state *s, unsigned int, value **);
+value *mem_get_string(arena_state *s, unsigned int, value **);
 value *mem_get_pointer(arena_state *s, unsigned int, value **);
 value *mem_string(arena_state *s, unsigned int, value **);
 value *mem_is_rw(arena_state *s, unsigned int, value **);
@@ -280,6 +282,7 @@ value *dyn_call_void(arena_state *s, unsigned int, value **);
 value *dyn_call_int(arena_state *s, unsigned int, value **);
 value *dyn_call_float(arena_state *s, unsigned int, value **);
 value *dyn_call_ptr(arena_state *s, unsigned int, value **);
+value *dyn_c_float(arena_state *s, unsigned int, value **);
 
 /*
  * PCRE functions
